- `Aimée Gibbons (NASA Goddard Space Flight Center) <https://science.gsfc.nasa.gov/sed/bio/aimee.c.gibbons/>`_
- `Tyler Sutterley (University of Washington) <http://psc.apl.uw.edu/people/investigators/tyler-sutterley/>`_
